% Prototype Filter Calculation code. 
% Modified from R. Kakarala's design example. 
%
% Modified by Gregory Scandalis 
% Gregory Pat Scandalis 
% Fundementals of Digital Signal Processing
% UC Berkeley, Spring 2004
% I decided to go for the max number of taps and set Fc to 1/128 per the
% specification.  I qualitatively note that the filter Davis Pan describes in Figure 4, p63 
% appears to not have a very sharp cutoff and seems to vary a bit in the
% stop band. 
% 
% I also note that the plot of my hw appears to be similar the image of
% h[n] in Figure 3, p63. 
%

% clear any old vars out of the workspace
clear; 

%Specification is that Fc at F = 1/128 
Fc = 1/128; 

% Initially Fpe (passband edge) and Fse (stop band edge) are within 10% of Fc
Fpe = Fc*(.9); Fse=Fc*(1.1)

% Goal is that eps_p (pass band variation) be 1%
eps_p = 0.01; 

% Goal is that As (stopband attenuation) be 40 db.  
As = 40;             
    
% Set the number of taps to be 512.    
M=512; 

% Calculate the Kaiser window
w = kaiserwindow(M,As);  

% n is an index vector so that we can use vector math
n = 0:(M-1);

% this is the ideal lowpass filter per the equation on page 7
hi = 2*Fc*sinc(2*Fc*(n - (M-1)/2));

% Window the ideal lowpass filter using the Kaiser window. 
% using vector to vector multiply
hw = w.*hi;   

% Calculate and plot the frequency response;
[Hw,F] = iirfreqresp(hw);  
plot(F,abs(Hw));
title('MPEG Layer 1 Prototype Filter');

% check if criteria were met
Hstop = Hw(abs(F)>=Fse);  % response in stopband
fprintf('Results...\n');
fprintf('Number of coefficients used = %4d\n',M);
fprintf('Min Stopband Attenuation (dB)=%8.5f\n',min(-20*log10(abs(Hstop)+eps)) );
fprintf('Target was=%8.5f (dB)\n',As);
Hpass = Hw(abs(F)<=Fpe);  % response in passband
fprintf('Max Passband Variation =%8.5f\n',max(abs(abs(Hpass)-1)) );
fprintf('Target was=%8.5f (dB)\n',eps_p);

pause; 
plot(hw);
title('Impulse Response h(n) for the MPEG Layer 1 Prototype filter'); 

pause; 

% computing the k-th filter impulse response. 
% using Cosine Modulation
N = length(hw); 
for k=0:31
   for n=1:N
      hk(n) = 2*hw(n)*cos(pi*(((2*k)+1)/64)*((n-1)-16));  
   end

% frequency response;
[Hk,F] = iirfreqresp(hk);  
plot(F,abs(Hk));
s = ['Cosine Modulation filter: ', num2str(k)]; 
title(s);

pause; 
end 



