function test(varargin)
%
% Calling Conventions
%
% test    - no debug, q = 16 bits
% test(0) - no debug, q = 16 bits
% test(1) - debug (displays analysis and synthesis filters), q = 16 bits
% test (0, 8) - no debug, q = 8; 
%
%
% test program for MPEG layer 1 compression
% Gregory Pat Scandalis 
% Fundementals of Digital Signal Processing
% UC Berkeley, Spring 2004
%
%
%
%
%

if length(varargin) == 0
    % Default no debug
    debug = 0; 
    % default q = 16 bits
    q = 16;  
end

if length(varargin) == 1
    debug(1) = varargin{1}(1); % Cell array indexing 
    % default q = 16 bits
    q        = 16;  
end

if length(varargin) == 2
    debug(1) = varargin{1}(1); % Cell array indexing 
    q(1)     = varargin{2}(1); % Cell array indexing 
end

if length(varargin) > 2
    fprintf('Too many arguments, using defaults, no debug, q=16\n'); 
    % Default no debug
    debug = 0; 
    % default q = 16 bits
    q = 16;  
end

% load a sound file
[x,fs,nbits]=wavread('test.wav');

% make it a row
x = x'; 

fprintf('Here is the original file before compression and decompression\n'); 
fprintf('Please hit <CR> to continue...\n'); 
pause; 
soundsc(x, fs); 

% pad the end of x to be a multiple of 32 
pad = 32 - mod(length(x), 32); 
for n=1:pad
    x = [x 0];
end

% call the compression function, the last argument of 1 is for debug.
fprintf('Begin Compression...\n'); 
y = compress(x,q,debug); 

% call the decompression function, the last argument of 1 is for debug. 
fprintf('Begin Decompression...\n'); 
xr = decompress(y,q,debug); 

soundsc(xr, fs); 
fprintf('Here is the decompressed filter coeffs\n'); 
fprintf('Please hit <CR> to continue...\n'); 
pause; 
wavwrite(xr, fs, 'testout.wav'); 




