function s = compress(x,q,debug) 
%  
% compress
% Gregory Pat Scandalis 
% Fundementals of Digital Signal Processing
% UC Berkeley, Spring 2004
%
% This is a the analysis function that accepts a vector from a sound file (x) and a bit
% quantization level (q).  It returns s a vector (s) of filter coeffs in groups
% of 32.   
%

% Load the table that contains h[n] for the prototype filter.  
PrototypeFilter; 

% initialize s
s = zeros(length(x), 1); 
% make it a row
s = s'; 

% for each filter in the bank
for k=0:31
   
    fprintf('filter %d\n', k); 
     
    % Calculate N
    N = length(h); 
    
    % calculate the k'th filter using cosine modulation
    % Notice that the equation is slightly different than 
    % from the notes because MATLAB indexes from 1 rather than 0
    for n=1:N
      hk(n) = 2*h(n)*cos(pi*(((2*k)+1)/64)*((n-1)-16));  
    end
      
    % This is here for debugging purposes
    % this will display each of the filters in the filter bank
    if isequal(debug,1)
        % frequency response;
        [Hk,F] = iirfreqresp(hk);  
        plot(F,abs(Hk));
        titleString = ['Cosine Modulation Analysis Filter: ', num2str(k)]; 
        title(titleString);
        fprintf('Please hit <CR> to continue...\n'); 
        pause;
    end     

    % convolution.  Since we are sub sampling every 32
    % its not necessary to calculate all y(t). 
    for t=1:32:length(x)
        y(t) = 0;           % initialize y(t) 
        for n=1:N
            if (t-(n-1)) > 0
                y(t) = y(t) + x(t-(n-1))*hk(n);
            end
        end
        
     % insert the subsample y into the correct k'th location in s. 
     s(t+k) = y(t);  
    end
end

% quantize s to q bits. Note that s will still be stored as a double, but
% it is understood that s could be stored in a q-bit representation. 
s = quantize(s,q); 


