function x = decompress(s,q,debug) 
%  
% decompress
% Gregory Pat Scandalis 
% Fundementals of Digital Signal Processing
% UC Berkeley, Spring 2004
%
% This is the decompression function.  It takes a stream of filter
% coeffs in groups of 32
%

% Load the table that contains h[n] for the prototype filter.  
PrototypeFilter; 

% reverse the quantizing on s
s = dequantize(s,q); 

% initialize output vector 
x = zeros(length(s), 1); 
% make x into a row
x = x'; 
    
% for each filter in the bank
for k=0:31
   
    fprintf('Synthesis filter %d\n', k); 
     
    % Calculate N.  Note that for MATLAB the number of taps ranges
    % from 1..N rather than 0..N-1
    N=length(h); 
    
    % calculate the k'th synthesis filter using cosine modulation
    % I think that this can be optimized, but for now I'm going to 
    % implement it as in the notes. 
    
    % as before just calculate hk,
    % calculate the k'th filter using cosine modulation
    % Notice that the equation is slightly different than 
    % from the notes because MATLAB indexes from 1 rather than 0
    for n=1:N
      hk(n) = 2*h(n)*cos(pi*(((2*k)+1)/64)*((n-1)-16));  
    end
    
    % now calculate gk
    % extra -1 because MATLAB indexes from 1 instead of 0 
    for n=1:N
      gk(n) = 32*hk(N-(n-1)); 
    end
    
    % This is here for debugging purposes
    % this will display each of the synthesis filters in the filter bank
    if isequal(debug,1)
        % frequency response;
        [Hk,F] = iirfreqresp(gk);  
        plot(F,abs(Hk));
        titleString = ['Cosine Modulation Synthesis Filter: ', num2str(k)]; 
        title(titleString);
        fprintf('Please hit <CR> to continue...\n'); 
        pause;
    end     

    % initialize skZeroPad to all zeros. 
    skZeroPad = zeros(length(s), 1); 
    %make it a row
    skZeroPad = skZeroPad'; 
    % zero padding
    for t=(k+1):32:length(s)
        skZeroPad(t-k) = s(t); 
    end
    
    % convolve the zero padded sk with the inverse filter.  
    for t=1:length(s)
       xk(t) = 0;           % initialize x(t) 
       for n=1:N
           if (t-(n-1)) > 0
               xk(t) = xk(t) + skZeroPad(t-(n-1))*gk(n);
           end
       end
   end
    
   % add together all the xk samples
   x = x + xk; 

end

